#
# spec file for package libheimdal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libheimdal
Version:        7.8.0
Release:        3.4
Summary:        The Heimdal implementation of the Kerberos 5 protocol
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
URL:            https://www.h5l.org
# patched source can be created with script heimdal-patch-source.sh:
# ./heimdal-patch-source.sh heimdal-%{version}.tar.gz
Source0:        heimdal-%{version}-patched.tar.bz2
Source2:        heimdal-patch-source.sh
Patch0:         heimdal-patched.diff
# PATCH-FIX-UPSTREAM bmwiedemann -- make build reproducible (boo#1047218)
Patch1:         reproducible.patch
# PATCH-FIX-UPSTREAM https://www.openwall.com/lists/oss-security/2023/02/08/1
Patch2:         heimdal-CVE-2022-45142.patch
BuildRequires:  automake >= 1.11
BuildRequires:  bison
BuildRequires:  db-devel >= 4.8
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  texinfo
BuildRequires:  perl(JSON)
BuildRequires:  pkgconfig(com_err)
BuildRequires:  pkgconfig(ncurses) >= 5.3
BuildRequires:  pkgconfig(sqlite3)

%description
Heimdal is an implementation of Kerberos 5 (and some more stuff) largely written
in Sweden (which was important when we started writing it, less so now).
It is freely available under a three clause BSD style license.

Other free implementations include the one from MIT, and Shishi.
Also Microsoft Windows and Sun's Java come with implementations of Kerberos.

This package only provides libraries and devel files (binaries have been removed),
libraries are required by 64-bit package of ICAClient version 13.2.

%package -n libasn1-8
Summary:        ASN.1 implementation from Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libasn1-8
This package contains the ASN.1 parser required for Heimdal.

%package -n libgssapi3
Summary:        GSSAPI implementation from Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libgssapi3
GSSAPI implementation from Heimdal.

%package -n libhcrypto4
Summary:        Cryptographic library from Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libhcrypto4
This package contains the cryptographic library required for Heimdal.

%package -n libhdb9
Summary:        Heimdal database backend library
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libhdb9
libhdb provides the backend support for Heimdal kdc and kadmind. Its
here where plugins for diffrent database engines can be pluged in and
extend support for here Heimdal get the principal and policy data
from.

Example of Heimdal backend are: Berkeley DB (BDB), NDB, LDAP.

%package -n libheimbase1
Summary:        Base library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libheimbase1
This package contains the base library for Heimdal Kerberos.

%package -n libheimedit0
Summary:        libedit fork of the Heimdal Kerberos project
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libheimedit0
libedit is a command line editing and history library. It is
designed to be used by interactive programs that allow the user
to type commands at a terminal prompt.

%package -n libheimntlm0
Summary:        NTLM implementation from Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libheimntlm0
This package contains the NTLM support library from and for Heimdal Kerberos.

%package -n libhx509-5
Summary:        X.509 implementation from Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libhx509-5
This package contains the X.509 support library from and for Heimdal Kerberos.

%package -n libkadm5clnt7
Summary:        Client library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libkadm5clnt7
This package contains the client library for Heimdal's kadmin program.

%package -n libkadm5srv8
Summary:        Server library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libkadm5srv8
This package contains the server library for Heimdal's kadmin program.

%package -n libkafs0
Summary:        KAFS support for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libkafs0
This package contains the library for supporting the in-kernel Andrew File System.

%package -n libkdc2
Summary:        Key Distribution Center library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libkdc2
This package contains the KDC support library.

%package -n libkrb5-26
Summary:        Kerberos 5 API for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libkrb5-26
This package contains the Kerberos 5 library.

%package -n libotp0
Summary:        One Time Password library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libotp0
This package contains the library for One Time Password support.

%package -n libroken18
Summary:        OS abstraction library for Heimdal Kerberos
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libroken18
This package contains a library that wraps or adds utility functions
missing from certain operating systems.

%package -n libsl0
Summary:        Implementation of a suggestion lister
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libsl0
This package contains a library that suggests commands in a "did you
mean" fashion.

%package -n libwind0
Summary:        An implementation of RFC 3454 (stringprep)
Group:          System/Libraries
Conflicts:      libheimdal < %{version}-%{release}

%description -n libwind0
This package contains an implementation of the stringprep library.

%package devel
Summary:        The Heimdal implementation of the Kerberos 5 protocol
Group:          Development/Libraries/C and C++
Requires:       db-devel >= 4.8
Requires:       glibc-devel
Requires:       libasn1-8 = %{version}-%{release}
Requires:       libgssapi3 = %{version}-%{release}
Requires:       libhcrypto4 = %{version}-%{release}
Requires:       libhdb9 = %{version}-%{release}
Requires:       libheimbase1 = %{version}-%{release}
Requires:       libheimedit0 = %{version}-%{release}
Requires:       libheimntlm0 = %{version}-%{release}
Requires:       libhx509-5 = %{version}-%{release}
Requires:       libkadm5clnt7 = %{version}-%{release}
Requires:       libkadm5srv8 = %{version}-%{release}
Requires:       libkafs0 = %{version}-%{release}
Requires:       libkdc2 = %{version}-%{release}
Requires:       libkrb5-26 = %{version}-%{release}
Requires:       libotp0 = %{version}-%{release}
Requires:       libroken18 = %{version}-%{release}
Requires:       libsl0 = %{version}-%{release}
Requires:       libwind0 = %{version}-%{release}
Requires:       pkgconfig(com_err)
Requires:       pkgconfig(ncurses) >= 5.3
Requires:       pkgconfig(sqlite3)
Conflicts:      krb5-devel
Conflicts:      krb5-mini-devel
Provides:       libheimdal = %{version}-%{release}
Obsoletes:      libheimdal < %{version}-%{release}

%description devel
Heimdal is an implementation of Kerberos 5 (and some more stuff) largely written
in Sweden (which was important when we started writing it, less so now).
It is freely available under a three clause BSD style license.

Other free implementations include the one from MIT, and Shishi.
Also Microsoft Windows and Sun's Java come with implementations of Kerberos.

This package only provides libraries and devel files (binaries have been removed),
libraries are required by 64-bit package of ICAClient version 13.2.

%prep
%autosetup -p1 -n heimdal-%{version}

%build
export SOURCE_HOST=OBS # for reproducible builds (boo#1084909)
autoreconf -fi
%configure \
  --with-sqlite3=%{_prefix}
%make_build

%install
%make_install

rm -rf %{buildroot}%{_libdir}/*.a
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig -n libasn1-8
%postun -p /sbin/ldconfig -n libasn1-8
%post -p /sbin/ldconfig -n libgssapi3
%postun -p /sbin/ldconfig -n libgssapi3
%post -p /sbin/ldconfig -n libhcrypto4
%postun -p /sbin/ldconfig -n libhcrypto4
%post -p /sbin/ldconfig -n libhdb9
%postun -p /sbin/ldconfig -n libhdb9
%post -p /sbin/ldconfig -n libheimbase1
%postun -p /sbin/ldconfig -n libheimbase1
%post -p /sbin/ldconfig -n libheimedit0
%postun -p /sbin/ldconfig -n libheimedit0
%post -p /sbin/ldconfig -n libheimntlm0
%postun -p /sbin/ldconfig -n libheimntlm0
%post -p /sbin/ldconfig -n libhx509-5
%postun -p /sbin/ldconfig -n libhx509-5
%post -p /sbin/ldconfig -n libkadm5clnt7
%postun -p /sbin/ldconfig -n libkadm5clnt7
%post -p /sbin/ldconfig -n libkadm5srv8
%postun -p /sbin/ldconfig -n libkadm5srv8
%post -p /sbin/ldconfig -n libkafs0
%postun -p /sbin/ldconfig -n libkafs0
%post -p /sbin/ldconfig -n libkdc2
%postun -p /sbin/ldconfig -n libkdc2
%post -p /sbin/ldconfig -n libkrb5-26
%postun -p /sbin/ldconfig -n libkrb5-26
%post -p /sbin/ldconfig -n libotp0
%postun -p /sbin/ldconfig -n libotp0
%post -p /sbin/ldconfig -n libroken18
%postun -p /sbin/ldconfig -n libroken18
%post -p /sbin/ldconfig -n libsl0
%postun -p /sbin/ldconfig -n libsl0
%post -p /sbin/ldconfig -n libwind0
%postun -p /sbin/ldconfig -n libwind0

%files -n libasn1-8
%{_libdir}/libasn1.so.8*

%files -n libgssapi3
%{_libdir}/libgssapi.so.3*

%files -n libhcrypto4
%{_libdir}/libhcrypto.so.4*

%files -n libhdb9
%{_libdir}/libhdb.so.9*

%files -n libheimbase1
%{_libdir}/libheimbase.so.1*

%files -n libheimedit0
%{_libdir}/libheimedit.so.0*

%files -n libheimntlm0
%{_libdir}/libheimntlm.so.0*

%files -n libhx509-5
%{_libdir}/libhx509.so.5*

%files -n libkadm5clnt7
%{_libdir}/libkadm5clnt.so.7*

%files -n libkadm5srv8
%{_libdir}/libkadm5srv.so.8*

%files -n libkafs0
%{_libdir}/libkafs.so.0*

%files -n libkdc2
%{_libdir}/libkdc.so.2*

%files -n libkrb5-26
%{_libdir}/libkrb5.so.26*

%files -n libotp0
%{_libdir}/libotp.so.0*

%files -n libroken18
%{_libdir}/libroken.so.18*

%files -n libsl0
%{_libdir}/libsl.so.0*

%files -n libwind0
%{_libdir}/libwind.so.0*

%files devel
%license LICENSE
%doc NEWS README TODO
%{_includedir}/*.h
%dir %{_includedir}/gssapi
%{_includedir}/gssapi/*.h
%dir %{_includedir}/hcrypto
%{_includedir}/hcrypto/*.h
%dir %{_includedir}/kadm5
%{_includedir}/kadm5/*.h
%dir %{_includedir}/krb5
%{_includedir}/krb5/*.h
%dir %{_includedir}/roken
%{_includedir}/roken/*.h
%{_libdir}/*.so
%{_infodir}/*.info%{?ext_info}

%changelog
* Thu Apr  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add heimdal-CVE-2022-45142.patch: Fix logic inversion introduced
  when fixing/backporting CVE-2022-3437 (CVE-2022-45142,
  boo#1208992).
* Tue Jan 10 2023 Marcus Meissner <meissner@suse.com>
- replace libheimdal conflicts by obsoletes / provides to provide a
  smooth update in the new libheimdal-devel.
* Wed Dec 21 2022 enzokiel@kabelmail.de
- Update to version 7.8.0
  + This release includes both the Heimdal 7.7.1 Security
    Vulnerability fixes and non-Security bug fixes/improvements.
  + Security Vulnerabilities:
  - CVE-2022-42898 PAC parse integer overflows
  - CVE-2022-3437 Overflows and non-constant time leaks in
    DES{,3} and arcfour
  - CVE-2022-41916 Fix Unicode normalization read of 1 bytes past
    end of array
  - CVE-2021-44758 A null pointer de-reference DoS in SPNEGO
    acceptors
  - CVE-2021-3671 A null pointer de-reference when handling
    missing sname in TGS-REQ
  - CVE-2022-44640 Heimdal KDC: invalid free in ASN.1 codec
    Note that CVE-2022-44640 is a severe vulnerability,
    possibly a 10.0 on the Common Vulnerability Scoring
    System (CVSS) v3, as we believe it should be possible to
    get an RCE on a KDC, which means that credentials can be
    compromised that can be used to impersonate anyone in a
    realm or forest of realms.
    Heimdal's ASN.1 compiler generates code that allows
    specially crafted DER encodings of CHOICEs to invoke the
    wrong free function on the decoded structure upon decode
    error. This is known to impact the Heimdal KDC, leading to
    an invalid free() of an address partly or wholly under the
    control of the attacker, in turn leading to a potential
    remote code execution (RCE) vulnerability.
    This error affects the DER codec for all extensible CHOICE
    types used in Heimdal, though not all cases will be
    exploitable. We have not completed a thorough analysis of
    all the Heimdal components affected, thus the Kerberos
    client, the X.509 library, and other parts, may be affected
    as well.
    This bug has been in Heimdal's ASN.1 compiler since 2005,
    but it may only affect Heimdal 1.6 and up. It was first
    reported by Douglas Bagnall, though it had been found
    independently by the Heimdal maintainers via fuzzing a few
    weeks earlier.
    While no zero-day exploit is known, such an exploit will
    likely be available soon after public disclosure.
  - CVE-2019-14870: Validate client attributes in
    protocol-transition
  - CVE-2019-14870: Apply forwardable policy in
    protocol-transition
  - CVE-2019-14870: Always lookup impersonate client in DB
  + Other changes:
  - Bugs found by UBSAN (including the incorrect encoding of
    unconstrained INTEGER value -1).
  - Errors found by the LLVM scan-build static analyzer.
  - Errors found by the valgrind memory debugger.
  - Work around GCC Bug 95189 (memcmp wrongly stripped like
    strcmp).
  - Correct ASN.1 OID typo for SHA-384
  - Fix a deadlock in in the MEMORY ccache type.
  - TGS: strip forwardable and proxiable flags if the server is
    disallowed.
  - CVE-2019-14870: Validate client attributes in
    protocol-transition
  - CVE-2019-14870: Apply forwardable policy in
    protocol-transition
  - CVE-2019-14870: Always lookup impersonate client in DB
  - Incremental HDB propagation improvements
    Refactor send_diffs making it progressive
    Handle partial writes on non-blocking sockets
    Disable Nagle in iprop master and slave
    Use async I/O
    Don't send I_HAVE in response to AYT
    Do not recover log in kadm5_get_principal()
    Don't send diffs to slaves with not yet known version
    Don't stutter in send_diffs
  - Optional backwards-compatible anon-pkinit behavior
- Removed heimdal-7.7.0-autoconf-2.70.patch, fixed upstream.
* Thu Jun 30 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add ldconfig scriptlets.
- Fix 'Conflicts:' tags.
- Remove obsolete macros and conditionals.
- Ran spec-cleaner.
* Tue Jun 28 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add heimdal-7.7.0-autoconf-2.70.patch: Fix build with autoconf
  2.70 (gh#heimdal/heimdal#856).
* Wed May 25 2022 Jan Engelhardt <jengelh@inai.de>
- Apply Shared Library Packaging Policy and resolve rpmlint
  errors like "libheimdal.x86_64: E: shlib-policy-name-error
  SONAME: libasn1.so.8, expected package suffix: 8"
* Sun Jun 23 2019 enzokiel@kabelmail.de
- Update to version 7.7.0
  + Bug fixes:
  - PKCS#11 hcrypto back-end:
    + initialize the p11_module_load function list
    + verify that not only is a mechanism present but that its
    mechanism info states that it offers the required
    encryption, decryption or digest services
  - krb5:
    + Starting with 7.6, Heimdal permitted requesting
    authenticated anonymous tickets. However, it did not
    verify that a KDC in fact returned an anonymous ticket
    when one was requested.
    + Cease setting the KDCOption reaquest_anonymous flag when
    issuing S4UProxy (constrained delegation) TGS requests.
    + when the Win2K PKINIT compatibility option is set, do not
    require krbtgt otherName to match when validating KDC
    certificate.
    + set PKINIT_BTMM flag per Apple implementation
    + use memset_s() instead of memset()
  - kdc:
    + When generating KRB5SignedPath in the AS, use the reply
    client name rather than the one from the request, so
    validation will work correctly in the TGS.
    + allow checksum of PA-FOR-USER to be HMAC_MD5. Even if TGT
    used an enctype with a different checksum. Per [MS-SFU]
    2.2.1 PA-FOR-USER the checksum is always HMAC_MD5, and
    that's what Windows and MIT clients send.
    In Heimdal both the client and kdc use instead the
    checksum of the TGT, and therefore work with each other
    but Windows and MIT clients fail against Heimdal KDC.
    Both Windows and MIT KDC would allow any keyed checksum
    to be used so Heimdal client work fine against it.
    Change Heimdal KDC to allow HMAC_MD5 even for non RC4
    based TGT in order to support per-spec clients.
    + use memset_s() instead of memset()
    + Detect Heimdal 1.0 through 7.6 clients that issue
    S4UProxy (constrained delegation) TGS Requests with the
    request anonymous flag set. These requests will be
    treated as S4UProxy requests and not anonymous requests.
  - HDB:
    + Set SQLite3 backend default page size to 8KB.
    + Add hdb_set_sync() method
  - kadmind:
    + disable HDB sync during database load avoiding
    unnecessary disk i/o.
  - ipropd:
    + disable HDB sync during receive_everything. Doing an
    fsync per-record when receiving the complete HDB is a
    performance disaster. Among other things, if the HDB is
    very large, then one slave receving a full HDB can cause
    other slaves to timeout and, if HDB write activity is
    high enough to cause iprop log truncation, then also need
    full syncs, which leads to a cycle of full syncs for all
    slaves until HDB write activity drops.
    Allowing the iprop log to be larger helps, but improving
    receive_everything() performance helps even more.
  - kinit:
    + Anonymous PKINIT tickets discard the realm information
    used to locate the issuing AS. Store the issuing realm in
    the credentials cache in order to locate a KDC which can
    renew them.
    + Do not leak the result of krb5_cc_get_config() when
    determining anonymous PKINIT start realm.
  - klist:
    + Show transited-policy-checked, ok-as-delegate and
    anonymous flags when listing credentials.
  - tests:
    + Regenerate certs so that they expire before the 2038
    armageddon so the test suite will pass on 32-bit
    operating systems until the underlying issues can be
    resolved.
  - Solaris:
    + Define _STDC_C11_BCI for memset_s prototype
  - build tooling:
    + Convert from python 2 to python 3
  - documentation:
    + rename verify-password to verify-password-quality
    + hprop default mode is encrypt
    + kadmind "all" permission does not include "get-keys"
    + verify-password-quality might not be stateless
- Version 7.6.0
  + Security (#555):
  - CVE-2018-16860 Heimdal KDC: Reject PA-S4U2Self with unkeyed
    checksum
    When the Heimdal KDC checks the checksum that is placed on
    the S4U2Self packet by the server to protect the requested
    principal against modification, it does not confirm that
    the checksum algorithm that protects the user name
    (principal) in the request is keyed. This allows a
    man-in-the-middle attacker who can intercept the request to
    the KDC to modify the packet by replacing the user name
    (principal) in the request with any desired user name
    (principal) that exists in the KDC and replace the checksum
    protecting that name with a CRC32 checksum (which requires
    no prior knowledge to compute).
    This would allow a S4U2Self ticket requested on behalf of
    user name (principal) user@EXAMPLE.COM to any service to be
    changed to a S4U2Self ticket with a user name (principal) of
    Administrator@EXAMPLE.COM. This ticket would then contain
    the PAC of the modified user name (principal).
  - CVE-2019-12098, client-only:
    RFC8062 Section 7 requires verification of the PA-PKINIT-KX
    key exchange when anonymous PKINIT is used. Failure to do
    so can permit an active attacker to become a
    man-in-the-middle.
  + Bug fixes:
  - Happy eyeballs: Don't wait for responses from
    known-unreachable KDCs.
  - kdc:
    + check return copy_Realm, copy_PrincipalName,
    copy_EncryptionKey
  - kinit:
    + cleanup temporary ccaches
    + see man page for "kinit --anonymous" command line syntax
    change
  - kdc:
    + Make anonymous AS-requests more RFC8062-compliant.
    Updated expired test certificates
  - Solaris:
    + PKCS#11 hcrypto backend broken since 7.0.1
    + Building with Sun Pro C
  + Features:
  - kuser: support authenticated anonymous AS-REQs in kinit
  - kdc: support for anonymous TGS-REQs
  - kgetcred support for anonymous service tickets
  - Support builds with OpenSSL 1.1.1
- fixed heimdal-patched.diff and reproducible.patch
* Tue Aug  7 2018 bwiedemann@suse.com
- Add reproducible.patch to override build date (boo#1047218)
- Use constant hostname (boo#1084909)
* Fri Dec 29 2017 joerg.lorenzen@ki.tng.de
- Update to version 7.5.0
  - Security
  - Fix CVE-2017-17439, which is a remote denial of service
    vulnerability:
    In Heimdal 7.1 through 7.4, remote unauthenticated attackers
    are able to crash the KDC by sending a crafted UDP packet
    containing empty data fields for client name or realm.
  - Bug fixes
  - Handle long input lines when reloading database dumps.
  - In pre-forked mode (default on Unix), correctly clear the
    process ids of exited children, allowing new child processes
    to replace the old.
  - Fixed incorrect KDC response when no-cross realm TGT exists,
    allowing client requests to fail quickly rather than time
    out after trying to get a correct answer from each KDC.
- Fixed heimdal-patched.diff.
- Removed Avoid_NULL_structure_pointer_member_dereference.patch,
  fixed upstream.
* Thu Dec  7 2017 joerg.lorenzen@ki.tng.de
- Added Avoid_NULL_structure_pointer_member_dereference.patch,
  fixes (bsc#1071675).
* Thu Aug  3 2017 joerg.lorenzen@ki.tng.de
- Update to version 7.4.0
  - Security
  - Fix CVE-2017-11103: Orpheus' Lyre KDC-REP service name
    validation.
    This is a critical vulnerability.
    In _krb5_extract_ticket() the KDC-REP service name must be
    obtained from encrypted version stored in 'enc_part' instead
    of the unencrypted version stored in 'ticket'.
    Use of the unecrypted version provides an opportunity for
    successful server impersonation and other attacks.
    Identified by Jeffrey Altman, Viktor Duchovni and
    Nico Williams.
    See https://www.orpheus-lyre.info/ for more details.
- Fixed heimdal-patched.diff.
* Thu Jun 15 2017 joerg.lorenzen@ki.tng.de
- Update to version 7.3.0
  - Security
    + Fix transit path validation. Commit f469fc6 (2010-10-02)
    inadvertently caused the previous hop realm to not be added
    to the transit path of issued tickets. This may, in some
    cases, enable bypass of capath policy in Heimdal versions 1.5
    through 7.2.
    Note, this may break sites that rely on the bug. With the bug
    some incomplete [capaths] worked, that should not have.
    These may now break authentication in some cross-realm
    configurations. (CVE-2017-6594)
- Version 7.2.0
  - Bug fixes
    + Portability improvements.
    + More strict parsing of encoded URI components in HTTP KDC.
    + Fixed memory leak in malloc error recovery in NTLM GSSAPI
    mechanism.
    + Avoid overly specific CPU info in krb5-config in aid of
    reproducible builds.
    + Don't do AFS string-to-key tests when feature is disabled.
    + Skip mdb_stat test when the command is not available.
    + Windows: update SHA2 timestamp server.
    + hdb: add missing export
    hdb_generate_key_set_password_with_ks_tuple.
    + Fix signature of hdb_generate_key_set_password().
    + Windows: enable KX509 support in the KDC.
    + kdc: fix kx509 service principal match.
    + iprop: handle case where master sends nothing new.
    + ipropd-slave: fix incorrect error codes.
    + Allow choice of sqlite for HDB pref.
    + check-iprop: don't fail to kill daemons.
    + roken: pidfile -> rk_pidfile.
    + kdc: _kdc_do_kx509 fix use after free error.
    + Do not detect x32 as 64-bit platform.
    + No sys/ttydefaults.h on CYGWIN.
    + Fix check-iprop races.
    + roken_detach_prep() close pipe.
- Fixed heimdal-patched.diff.
* Thu Feb  2 2017 jengelh@inai.de
- Summary and RPM group update. Do a direct call to ldconfig
  where possible.
* Sat Jan  7 2017 joerg.lorenzen@ki.tng.de
- Update to version 7.1.0
- Removed heimdal-version-script-client.map.patch, fixed upstream.
- Fixed heimdal-patched.diff.
- Unfortunately there is no updated changelog file in tarball,
  changes can be seen in source code version control systems
  history log.
* Sat Sep  5 2015 joerg.lorenzen@ki.tng.de
- Added a patched instead of the original tarball because only
  shared libraries will be build and source files of these (not to
  be build) programs have problematic licenses.
- Added script heimdal-patch-source.sh to sources.
- Added patch heimdal-patched.diff that fixes configure.ac and
  several Makefile.am files to successfully build patched source.
- Removed unneeded dependencies in spec file for build.
* Wed Sep  2 2015 joerg.lorenzen@ki.tng.de
- Added Conflicts tags to spec file because devel package conflicts
  with krb5-devel and krb5-mini-devel.
* Tue Sep  1 2015 joerg.lorenzen@ki.tng.de
- Some changes in spec file to enable build for SLES.
* Sun Aug 30 2015 joerg.lorenzen@ki.tng.de
- Initial package, version 1.6rc2
- Added patch heimdal-version-script-client.map.patch to add file
  version-script-client.map (File is present in git for tag 1.6rc2
  but missing in tarball).
